@@ -27,44 +27,9 @@ if TYPE_CHECKING:
     from .typing import EnsureStrategyIterableType, EnsureStrategyType, VersionType
 
 
-class _AwesomeVersionBase(str):
-    """Base class for AwesomeVersion to allow the usage of the default JSON encoder."""
-
-    def __init__(self, string: str):
-        str.__init__(string)
-
-    def __new__(
-        cls,
-        version: str,
-        *_: Any,
-        **__: Any,
-    ) -> "_AwesomeVersionBase":
-        """Create a new AwesomeVersion object."""
-
-        return super().__new__(cls, version)
-
-
-class AwesomeVersion(_AwesomeVersionBase):
+class AwesomeVersion(str):
     """
     AwesomeVersion class.
-
-    **args**:
-
-    version:
-        The version to create a AwesomeVersion object from
-
-    **kwargs**:
-
-    ensure_strategy:
-        Match the AwesomeVersion object against spesific
-        strategies when creating if. If it does not match
-        AwesomeVersionStrategyException will be raised
-
-    find_first_match:
-        If True, the version given will be scanned for the first
-        match of the given ensure_strategy. Raises
-        AwesomeVersionStrategyException If it is not found
-        for any of the given strategies.
     """
 
     _version: str = ""
@@ -82,7 +47,27 @@ class AwesomeVersion(_AwesomeVersionBase):
         find_first_match: bool = False,
         **kwargs: Any,
     ) -> None:
-        """Initialize AwesomeVersion."""
+        """
+        Initialize AwesomeVersion.
+
+        **args**:
+
+        version:
+            The version to create a AwesomeVersion object from
+
+        **kwargs**:
+
+        ensure_strategy:
+            Match the AwesomeVersion object against spesific
+            strategies when creating if. If it does not match
+            AwesomeVersionStrategyException will be raised
+
+        find_first_match:
+            If True, the version given will be scanned for the first
+            match of the given ensure_strategy. Raises
+            AwesomeVersionStrategyException If it is not found
+            for any of the given strategies.
+        """
         if args:
             warn(
                 "Positional argument for ensure_strategy is deprecated. "
@@ -141,7 +126,17 @@ class AwesomeVersion(_AwesomeVersionBase):
         if self._version and self._version[-1] == ".":
             self._version = self._version[:-1]
 
-        super().__init__(self._version)
+        str.__init__(self._version)
+
+    def __new__(
+        cls,
+        version: str,
+        *_: Any,
+        **__: Any,
+    ) -> AwesomeVersion:
+        """Create a new AwesomeVersion object."""
+
+        return super().__new__(cls, version)
 
     def __enter__(self) -> AwesomeVersion:
         return self
@@ -218,9 +213,9 @@ class AwesomeVersion(_AwesomeVersionBase):
             raise AwesomeVersionCompareException("Not a valid AwesomeVersion object")
         return AwesomeVersionDiff(
             {
-                "major": self.major != compareto.major,
-                "minor": self.minor != compareto.minor,
-                "patch": self.patch != compareto.patch,
+                "major": str(self.major) != str(compareto.major),
+                "minor": str(self.minor) != str(compareto.minor),
+                "patch": str(self.patch) != str(compareto.patch),
                 "modifier": self.modifier != compareto.modifier,
                 "strategy": self.strategy != compareto.strategy,
             }
@@ -317,7 +312,7 @@ class AwesomeVersion(_AwesomeVersionBase):
                 [
                     section.split(self.modifier_type)[-1]
                     for section in self.string.split(".")
-                    if modifier is None or section != modifier
+                    if section and (modifier is None or section != modifier)
                 ]
             )
         return self._sections
@@ -327,13 +322,14 @@ class AwesomeVersion(_AwesomeVersionBase):
         """
         Return a AwesomeVersion representation of the major version.
 
-        Will return None if the versions is not semver/buildver/calver/simplever.
+        Will return None if the versions is not semver/buildver/calver/simplever/pep440.
         """
         if self.strategy not in (
             AwesomeVersionStrategy.SEMVER,
             AwesomeVersionStrategy.BUILDVER,
             AwesomeVersionStrategy.CALVER,
             AwesomeVersionStrategy.SIMPLEVER,
+            AwesomeVersionStrategy.PEP440,
         ):
             return None
         return AwesomeVersion(self.section(0))
@@ -343,13 +339,18 @@ class AwesomeVersion(_AwesomeVersionBase):
         """
         Return a AwesomeVersion representation of the minor version.
 
-        Will return None if the versions is not semver/simplever/calver
+        Will return None if the versions is not semver/simplever/calver/pep440
         Will return None if the version does not have at least 2 sections.
         """
-        if self.strategy not in (
-            AwesomeVersionStrategy.SEMVER,
-            AwesomeVersionStrategy.CALVER,
-            AwesomeVersionStrategy.SIMPLEVER,
+        if (
+            self.strategy
+            not in (
+                AwesomeVersionStrategy.SEMVER,
+                AwesomeVersionStrategy.CALVER,
+                AwesomeVersionStrategy.SIMPLEVER,
+                AwesomeVersionStrategy.PEP440,
+            )
+            or self.sections < 2
         ):
             return None
 
@@ -360,7 +361,7 @@ class AwesomeVersion(_AwesomeVersionBase):
         """
         Return a AwesomeVersion representation of the patch version.
 
-        Will return None if the versions is not semver/simplever/calver
+        Will return None if the versions is not semver/simplever/calver/pep440
         Will return None if the version does not have at least 3 sections.
         """
         if (
@@ -369,6 +370,7 @@ class AwesomeVersion(_AwesomeVersionBase):
                 AwesomeVersionStrategy.SEMVER,
                 AwesomeVersionStrategy.CALVER,
                 AwesomeVersionStrategy.SIMPLEVER,
+                AwesomeVersionStrategy.PEP440,
             )
             or self.sections < 3
         ):
